Omx Maps Xml
============

A declarative approach to making sense of XML-documents. Omx aims to avoid
making your eyes bleed and trigger unnecessary death [0]_ of those around you.

A declarative description of the xml namespaces you want to grok is used to
both parse and serialize xml documents. Despite being used `in production` for
several years on some of hobby projects by yours truly `omx` is still in its
infancy. But it does support some fancy features like namespaces which
otherwise is most of time ignored or just implemented wrong.

.. [0] When working with xml death may be the preferred option. And could even
   be considered kind.

